package Server::Info;
use strict;
use warnings;
use base qw/Class::Accessor::Lvalue::Fast/;

use Net::SSH qw/ssh_cmd/;
use Text::CSV;

use Server::Info::CPU;
use Server::Info::Memory;

__PACKAGE__->mk_accessors(qw/host cpu memory/);

sub get {
    my ($class, $host) = @_;
    my $self = $class->new({ 
        host => $host,
    });

    my $cpuinfo = ssh_cmd $host, 'cat /proc/cpuinfo';
    my ($cpu_model, $num_of_cpu) = parse_cpuinfo($cpuinfo);
    $self->cpu = Server::Info::CPU->new({
        model  => $cpu_model,
        number => $num_of_cpu,
    });

    my $meminfo = ssh_cmd $host, "free | grep 'Mem:'";
    $self->memory = Server::Info::Memory->new({
        size => parse_meminfo($meminfo),
    });
    $self;
}

sub as_csv {
    my $self = shift;
    my $csv = Text::CSV->new;
    $csv->combine(
        $self->host,
        $self->cpu->model,
        $self->cpu->number,
        $self->memory->size,
    );
    return $csv->string;
}

sub parse_cpuinfo {
    my $cpuinfo = shift;
    my ($cpu_model, $num_of_cpu);

    my @lines = split /\n/, $cpuinfo;
    for my $line (@lines) {
        if ($line =~ m/^model name\s+:(.*)/) {
            $num_of_cpu++;
            $cpu_model = $1;
        }
    }
    return ($cpu_model, $num_of_cpu);
}

sub parse_meminfo {
    my $meminfo = shift;
    $meminfo =~ m/^Mem:\s+(\d+)/;
    return $1;
}

1;
