package Server::Info;
use strict;
use warnings;
use base qw/Class::Accessor::Lvalue::Fast/;

use Net::SSH qw/ssh_cmd/;
use Text::CSV;

use Server::Info::CPU;
use Server::Info::Memory;
use Module::Pluggable search_path => ['Server::Info'];

__PACKAGE__->mk_accessors(qw/host cpu memory/);

sub get {
    my ($class, $host) = @_;
    my $self = $class->new({ 
        host => $host,
    });
    my @plugins = $self->plugins;

    warn $_ for @plugins;

    $self->cpu    = Server::Info::CPU->get($host);
    $self->memory = Server::Info::Memory->get($host);
    $self;
}

sub as_csv {
    my $self = shift;
    my $csv = Text::CSV->new;
    $csv->combine(
        $self->host,
        $self->cpu->model,
        $self->cpu->number,
        $self->memory->size,
    );
    return $csv->string;
}

1;
