#!/usr/local/bin/perl
use strict;
use warnings;
use Net::SSH qw/ssh_cmd/;
use Text::ASCIITable;

for my $addr (@ARGV) {
    my $cpuinfo = ssh_cmd $addr, 'cat /proc/cpuinfo';
    my ($cpu_model, $num_of_cpu) = parse_cpuinfo($cpuinfo);
    print cpuinfo_as_table($addr, $cpu_model, $num_of_cpu);
}

sub parse_cpuinfo {
    my $cpuinfo = shift;
    my ($cpu_model, $num_of_cpu);

    my @lines = split /\n/, $cpuinfo;
    for my $line (@lines) {
        if ($line =~ m/^model name\s+:(.*)/) {
            $num_of_cpu++;
            $cpu_model = $1;
        }
    }
    return ($cpu_model, $num_of_cpu);
}

sub cpuinfo_as_table {
    my ($addr, $cpu_model, $num_of_cpu) = @_;
    my $t = Text::ASCIITable->new;
    $t->setCols('Title', 'Value');
    $t->alignCol('Value', 'left');
    $t->addRow('Host', $addr);
    $t->addRow('CPU model', $cpu_model);
    $t->addRow('Number of CPU', $num_of_cpu);
    $t->draw;
}
