#!/usr/local/bin/perl
use strict;
use warnings;
use Net::SSH qw/ssh_cmd/;
use Text::CSV;
use Text::ASCIITable;
use Getopt::Long;
use Number::Format qw/format_bytes/;

my $output_as_csv;
GetOptions('csv' => \$output_as_csv);

for my $addr (@ARGV) {
    my $cpuinfo = ssh_cmd $addr, 'cat /proc/cpuinfo';
    my ($cpu_model, $num_of_cpu) = parse_cpuinfo($cpuinfo);

    my $meminfo = ssh_cmd $addr, "free | grep 'Mem:'";
    my $amount_of_memory = parse_meminfo($meminfo);
    my @args = ($addr, $cpu_model, $num_of_cpu, format_bytes($amount_of_memory));
    if ($output_as_csv) {
        print sysinfo_as_csv(@args), "\n";
    } else {
        print sysinfo_as_table(@args);
    }
}

sub parse_cpuinfo {
    my $cpuinfo = shift;
    my ($cpu_model, $num_of_cpu);

    my @lines = split /\n/, $cpuinfo;
    for my $line (@lines) {
        if ($line =~ m/^model name\s+:(.*)/) {
            $num_of_cpu++;
            $cpu_model = $1;
        }
    }
    return ($cpu_model, $num_of_cpu);
}

sub parse_meminfo {
    my $meminfo = shift;
    $meminfo =~ m/^Mem:\s+(\d+)/;
    return $1;
}

sub sysinfo_as_table {
    my ($addr, $cpu_model, $num_of_cpu, $amount_of_memory) = @_;
    my $t = Text::ASCIITable->new;
    $t->setCols('Title', 'Value');
    $t->alignCol('Value', 'left');
    $t->addRow('Host', $addr);
    $t->addRow('CPU model', $cpu_model);
    $t->addRow('Number of CPU', $num_of_cpu);
    $t->addRow('Amount of Memory', $amount_of_memory);
    return $t->draw;
}

sub sysinfo_as_csv {
    my ($addr, $cpu_model, $num_of_cpu, $amount_of_memory) = @_;
    my $csv = Text::CSV->new;
    $csv->combine($addr, $cpu_model, $num_of_cpu, $amount_of_memory);
    return $csv->string;
}
